CommuteFilter

Struct CommuteFilter 

pub struct CommuteFilter {
    pub allow_imprecise_addresses: Option<bool>,
    pub commute_method: Option<String>,
    pub departure_time: Option<TimeOfDay>,
    pub road_traffic: Option<String>,
    pub start_coordinates: Option<LatLng>,
    pub travel_duration: Option<Duration>,
}
Parameters needed for commute search.

This type is not used in any activity, and only used as part of another schema.

Fields

allow_imprecise_addresses: Option<bool>

If true, jobs without street level addresses may also be returned. For city level addresses, the city center is used. For state and coarser level addresses, text matching is used. If this field is set to false or isn’t specified, only jobs that include street level addresses will be returned by commute search.

commute_method: Option<String>

Required. The method of transportation to calculate the commute time for.

departure_time: Option<TimeOfDay>

The departure time used to calculate traffic impact, represented as google.type.TimeOfDay in local time zone. Currently traffic model is restricted to hour level resolution.

road_traffic: Option<String>

Specifies the traffic density to use when calculating commute time.

start_coordinates: Option<LatLng>

Required. The latitude and longitude of the location to calculate the commute time from.

travel_duration: Option<Duration>

Required. The maximum travel time in seconds. The maximum allowed value is 3600s (one hour). Format is 123s.