pub struct HistogramQuery {
pub histogram_query: Option<String>,
}Expand description
The histogram request.
This type is not used in any activity, and only used as part of another schema.
Fields
histogram_query: Option<String>An expression specifies a histogram request against matching jobs for searches. See SearchJobsRequest.histogram_queries for details about syntax.