pub struct HistogramQueryResult {
pub histogram: Option<HashMap<String, i64>>,
pub histogram_query: Option<String>,
}Expand description
Histogram result that matches HistogramQuery specified in searches.
This type is not used in any activity, and only used as part of another schema.
Fields
histogram: Option<HashMap<String, i64>>A map from the values of the facet associated with distinct values to the number of matching entries with corresponding value. The key format is: * (for string histogram) string values stored in the field. * (for named numeric bucket) name specified in bucket() function, like for bucket(0, MAX, "non-negative"), the key will be non-negative. * (for anonymous numeric bucket) range formatted as -, for example, 0-1000, MIN-0, and 0-MAX.
histogram_query: Option<String>Requested histogram expression.